<?php

/**
 * Module de remontée de piratage
 *
 * Ce module détecte les requêtes malveillantes et les remonte
 * automatiquement à un endpoint centralisé.
 *
 * @author Maël Donnart <mael.donnart@nwb.fr>
 * @version 1.0.0
 */


// Cache des patterns chargés depuis le fichier JSON
$GLOBALS['cybersec_patterns_cache'] = null;

/**
 * Classe principale du module de remontée de piratage
 * Architecture optimisée selon demande CTO : configuration chargée une seule fois
 */
class CyberSecModule
{
    private string $endpoint;
    private string $auth_token;
    private string $site;
    private int $timeout = 2;
    private int $max_retries = 3;
    private array $retry_delays = [1, 2, 4];

    /**
     * Constructeur avec configuration hiérarchique optimisée
     *
     * @param string $site Le domaine du site web concerné. Clé utilisée pour regrouper les signalements.
     * @param string|null $endpoint L'URL de l'endpoint de signalement
     * @param string|null $auth_token Le token d'authentification
     * @throws Exception Si la configuration est invalide
     */
    public function __construct(string $site, ?string $endpoint = null, ?string $auth_token = null)
    {
        // Validation et typage strict des paramètres selon les bonnes pratiques PHP
        if (!is_string($site)) {
            throw new Exception("Le paramètre site doit être une chaîne de caractères");
        }

        if ($endpoint !== null && !is_string($endpoint)) {
            throw new Exception("Le paramètre endpoint doit être une chaîne de caractères ou null");
        }

        if ($auth_token !== null && !is_string($auth_token)) {
            throw new Exception("Le paramètre auth_token doit être une chaîne de caractères ou null");
        }

        // Configuration du site (obligatoire)
        if (empty($site)) {
            throw new Exception("Site manquant. Veuillez passer le site en paramètre du constructeur.");
        }
        $this->site = $site;

        // Configuration hiérarchique de l'endpoint
        // Priorité : paramètre constructeur > variable environnement > défaut
        if (!empty($endpoint)) {
            $this->endpoint = $endpoint;
        } elseif (!empty(getenv('CYBERSECMODULE_URL'))) {
            $this->endpoint = getenv('CYBERSECMODULE_URL');
        } else {
            $this->endpoint = 'https://n8n.kub.nwb.fr/webhook/signalHackingAttempt';
        }

        // Configuration hiérarchique du token d'authentification
        // Priorité : paramètre constructeur (pour les tests uniquement) > variable environnement
        if (!empty($auth_token)) {
            $this->auth_token = $auth_token;
        } elseif (!empty(getenv('CYBERSECMODULE_TOKEN'))) {
            $this->auth_token = getenv('CYBERSECMODULE_TOKEN');
        } else {
            throw new Exception("Token d'authentification manquant. Veuillez configurer la variable d'environnement CYBERSECMODULE_TOKEN ou passer le token en paramètre du constructeur.");
        }
    }

    /**
     * Signale une tentative de piratage détectée
     *
     * @param string $ip L'adresse IP de l'attaquant
     * @param string $reason La raison de la détection
     * @return void
     * @throws Exception Si les paramètres sont invalides
     */
    public function signalHackingAttempt(string $ip, string $reason): void
    {
        // Validation et typage strict des paramètres selon les bonnes pratiques PHP
        if (!is_string($ip)) {
            throw new Exception("Le paramètre ip doit être une chaîne de caractères");
        }

        // Validation de l'adresse IP avec filter_var (méthode recommandée)
        if (empty($ip) || filter_var($ip, FILTER_VALIDATE_IP) === false) {
            throw new Exception("Adresse IP manquante ou invalide");
        }

        if (!is_string($reason)) {
            throw new Exception("Le paramètre reason doit être une chaîne de caractères");
        }

        if (empty($reason) || strlen($reason) < 3) {
            throw new Exception("Raison manquante");
        }

        // Timestamp au format ISO8601 UTC
        $timestamp = gmdate('c');

        // Structure de données selon le nouveau format simplifié
        $data = [
            'ip' => $ip,
            'timestamp' => $timestamp,
            'pattern' => 'Tentative de piratage détectée pour la raison : ' . $reason,
            'site' => $this->site,
        ];

        // Tentative d'envoi avec retry
        for ($attempt = 0; $attempt < $this->max_retries; $attempt++) {
            // Préparation du payload JSON
            $jsonData = json_encode($data);

            // Préparation des en-têtes
            $headers = [
                'Content-Type: application/json',
                'Content-Length: ' . strlen($jsonData),
                'Authorization: Bearer ' . $this->auth_token
            ];

            // Envoi via cURL
            $ch = curl_init();

            curl_setopt_array($ch, [
                CURLOPT_URL => $this->endpoint,
                CURLOPT_POST => true,
                CURLOPT_POSTFIELDS => $jsonData,
                CURLOPT_HTTPHEADER => $headers,
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_TIMEOUT => $this->timeout,
                CURLOPT_FOLLOWLOCATION => false,
                CURLOPT_SSL_VERIFYPEER => true,
                CURLOPT_SSL_VERIFYHOST => 2
            ]);

            $response = curl_exec($ch);
            $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
            curl_close($ch);

            // Succès si code 200
            if ($httpCode === 200) {
                return;
            }

            // Si ce n'est pas la dernière tentative, attendre avant le retry
            if ($attempt < $this->max_retries - 1) {
                $delay = isset($this->retry_delays[$attempt]) ? $this->retry_delays[$attempt] : 1;
                sleep($delay);
            }
        }

        // Si toutes les tentatives ont échoué
        throw new Exception("Échec de l'envoi après {$this->max_retries} tentatives");
    }
}
